import "./App.css";
import React, { useEffect } from "react";
import InstructionPage from "./pages/instructionPage";
import SettingsPage from "./pages/settingsPages/settingsPage";
import UsernamePage from "./pages/usernamePage";
import PlayPage from "./pages/playPage";
import { BrowserRouter as Router, Route, Switch } from "react-router-dom";
import MainPage from "./pages/mainPage";
import SummaryPage from "./pages/summaryPage";
import { CssBaseline, ThemeProvider } from "@mui/material";
import { createTheme } from "@mui/material/styles";
import LoginPage from "./pages/loginPage";
import PrivateRoute from "./components/PrivateRoute";
import PlayRoute from "./components/PlayRoute";
import { loadUser } from "./actions/auth";
import store from "./store";
import { Provider } from "react-redux";

const theme = createTheme({
  palette: {
    mode: "dark",
    primary: {
      main: "#018786",
    },
    secondary: {
      main: "#f50057",
    },
    background: {
      default: "#252525",
      paper: "#333333",
    },
  },
});

function App() {
  useEffect(() => {
    store.dispatch(loadUser());
  }, []);

  return (
    <Provider store={store}>
      <ThemeProvider theme={theme}>
        <CssBaseline />
        <Router>
          <Switch>
            <Route path="/" exact component={MainPage} />
            <PrivateRoute path="/settings" component={SettingsPage} />
            <Route path="/instructions" exact component={InstructionPage} />
            <Route path="/username" exact component={UsernamePage} />
            <PlayRoute path="/play" exact component={PlayPage} />
            <Route path="/login" exact component={LoginPage} />
            <Route path="/summary" exact component={SummaryPage} />
          </Switch>
        </Router>
      </ThemeProvider>
    </Provider>
  );
}

export default App;
