import React, { useState, useEffect } from "react";
import { useForm, Form } from "./useForm";
import { TextField } from "@mui/material";
import Select from "./controls/Select";
import Input from "./controls/Input";
import Button from "@mui/material/Button";
import AdapterDateFns from "@mui/lab/AdapterDateFns";
import LocalizationProvider from "@mui/lab/LocalizationProvider";
import Box from "@mui/material/Box";
import DateTimePicker from "@mui/lab/DateTimePicker";
import Grid from "@mui/material/Grid";
import { useHistory } from "react-router-dom";
import { fetchTypes } from "../helpers/types";
import { fetchSigns } from "../helpers/signs";
import { postEmail } from "../helpers/emails";

//TODO validate date
const initialFValues = {
  subject: "",
  sender: "",
  recipient: "",
  date: new Date(),
  cc: "",
  body: "",
  type: 1,
  sign: [],
};

export default function EmailForm() {
  const [types, setTypes] = useState([]);
  const [signs, setSigns] = useState([]);
  const history = useHistory();

  useEffect(() => {
    fetchTypes().then((res) => setTypes(res));
    fetchSigns().then((res) => setSigns(res));
  }, []);

  const validate = (fieldValues = values) => {
    let temp = { ...errors };

    let type = -1;

    if ("subject" in fieldValues)
      temp.subject = fieldValues.subject ? "" : "Subject is required.";
    if ("sender" in fieldValues)
      temp.sender = fieldValues.sender ? "" : "Sender is required.";
    if ("recipient" in fieldValues)
      temp.recipient = fieldValues.recipient ? "" : "Recipient is required.";
    if ("type" in fieldValues) {
      console.log(fieldValues.type);
      type = fieldValues.type;
      temp.type = fieldValues.type ? "" : "Type is required.";
    }
    if ("sign" in fieldValues) {
      if (type === 1 && fieldValues.sign.length !== 0) {
        temp.sign = "Legitimate email cannot have signs";
      } else if (type !== 1) {
        temp.sign =
          fieldValues.sign.length !== 0 ? "" : "Choose at least one sign.";
      } else {
        temp.sign = "";
      }
    }
    setErrors({
      ...temp,
    });

    if (fieldValues === values)
      return Object.values(temp).every((x) => x === "");
  };

  const { values, setValues, errors, setErrors, handleInputChange, resetForm } =
    useForm(initialFValues, true, validate);

  const handleSubmit = (e) => {
    e.preventDefault();

    if (validate()) {
      postEmail(values).then(history.goBack());
    }
  };

  return (
    <Box>
      <Form onSubmit={handleSubmit} style={{ marginTop: 30 }}>
        <Grid container>
          <Grid item container justifyContent="center" xs={12} md={6}>
            <Input
              name="subject"
              label="Subject"
              value={values.subject}
              onChange={handleInputChange}
              error={errors.subject}
            />
            <Input
              label="Sender"
              name="sender"
              value={values.sender}
              onChange={handleInputChange}
              error={errors.sender}
            />
            <Input
              label="Recipient"
              name="recipient"
              value={values.recipient}
              onChange={handleInputChange}
              error={errors.recipient}
            />
            {/*TODO solve localization*/}
            <LocalizationProvider dateAdapter={AdapterDateFns}>
              <DateTimePicker
                ampm={false}
                label="Date&Time picker"
                inputFormat="yyyy/MM/dd HH:mm:SS"
                value={values.date}
                onChange={(value) => setValues({ ...values, date: value })}
                renderInput={(params) => <TextField {...params} />}
              />
            </LocalizationProvider>
          </Grid>

          <Grid item container justifyContent="center" xs={12} md={6}>
            <Input
              label="Cc"
              name="cc"
              value={values.cc}
              onChange={handleInputChange}
              error={errors.cc}
            />
            <Input
              label="Body"
              name="body"
              value={values.body}
              multiline={true}
              onChange={handleInputChange}
              error={errors.body}
            />
            <Select
              name="type"
              label="Type"
              value={values.type}
              onChange={handleInputChange}
              options={types}
              error={errors.type}
              type={"type"}
            />
            <Select
              name="sign"
              label="Signs"
              value={values.sign}
              onChange={handleInputChange}
              options={signs}
              multiple={true}
              type={"sign"}
              error={errors.sign}
            />
          </Grid>
          <Grid item container xs={12} justifyContent="center">
            <Button
              type="submit"
              size="large"
              variant="contained"
              sx={{ mt: 5 }}
            >
              Create
            </Button>
          </Grid>
        </Grid>
      </Form>
    </Box>
  );
}
