import * as React from "react";
import Box from "@mui/material/Box";
import Button from "@mui/material/Button";
import { Link } from "react-router-dom";
import Typography from "@mui/material/Typography";
import { createTheme, ThemeProvider } from "@mui/material/styles";
import MainHeader from "../components/MainHeader";
import Grid from "@mui/material/Grid";
import { TextField } from "@mui/material";
import { useState } from "react";
import axios from "axios";
import { useHistory } from "react-router";
import Alert from "@mui/material/Alert";

export default function UsernameForm() {
  const [username, setUsername] = useState("");
  const [errorBlankName, setErrorBlankName] = useState(false);
  const history = useHistory();

  function handleField(e) {
    setUsername(e.target.value);
  }

  function handleStart() {
    if (username.length === 0) {
      setErrorBlankName(true);
      return;
    }
    setErrorBlankName(false);
    localStorage.setItem("username", username);
    axios("http://localhost:8000/init/", {
      method: "POST",
      withCredentials: true,
      data: { username: username },
    })
      .then((r) => history.push(`/play`))
      .catch((err) => {
        console.log(err.response);
      });
  }

  const errorBox = (
    <Box
      sx={{
        display: "flex",
        width: "100%",
        justifyContent: "center",
        position: "absolute",
        mt: 10,
      }}
    >
      <Alert severity="error">Nickname cannot be blank!</Alert>
    </Box>
  );

  return (
    <div>
      <MainHeader />
      {errorBlankName && errorBox}

      <Box
        sx={{
          width: "100%",
          height: "100%",
          display: "flex",
          alignItems: "center",
          justifyContent: "center",
        }}
      >
        <Box
          sx={{
            display: "flex",
            flexDirection: "column",
            alignItems: "center",
          }}
        >
          <Typography variant="h4">Enter your nickname</Typography>
          <Box
            sx={{
              display: "flex",
              justifyContent: "center",
              mt: 2,
            }}
          >
            <TextField
              id="username"
              label="Username"
              value={username}
              onChange={handleField}
              sx={{ mr: 3 }}
            />
            <Button variant="contained" size="large" onClick={handleStart}>
              Next
            </Button>
          </Box>
        </Box>
      </Box>
    </div>
  );
}
