import * as React from "react";
import CssBaseline from "@mui/material/CssBaseline";
import AppBar from "@mui/material/AppBar";
import Box from "@mui/material/Box";
import Container from "@mui/material/Container";
import Toolbar from "@mui/material/Toolbar";
import Paper from "@mui/material/Paper";
import Stepper from "@mui/material/Stepper";
import Step from "@mui/material/Step";
import StepLabel from "@mui/material/StepLabel";
import Button from "@mui/material/Button";
import Link from "@mui/material/Link";
import Typography from "@mui/material/Typography";
import { createTheme, ThemeProvider } from "@mui/material/styles";
import MainHeader from "../components/MainHeader";
import Grid from "@mui/material/Grid";
import { IconButton, TextField } from "@mui/material";
import ArrowBackIcon from "@mui/icons-material/ArrowBack";
import { useState } from "react";
import axios from "axios";
import { useHistory } from "react-router";
import Alert from "@mui/material/Alert";
import { LocalizationProvider } from "@mui/lab";
import PropTypes from "prop-types";
import { Redirect } from "react-router-dom";
import { connect } from "react-redux";
import { login } from "../actions/auth";

LoginPage.propTypes = {
  login: PropTypes.func.isRequired,
  isAuthenticated: PropTypes.bool,
};

function LoginPage(props) {
  const [username, setUsername] = useState("");
  const [password, setPassword] = useState("");
  const history = useHistory();

  function handleLogin() {
    props.login(username, password);
  }

  function handleBack() {
    history.push("/");
  }
  const errorBox = (
    <Box
      sx={{
        display: "flex",
        width: "100%",
        justifyContent: "center",
        position: "absolute",
        mt: 10,
      }}
    >
      <Alert severity="error">Nickname cannot be blank!</Alert>
    </Box>
  );

  return (
    <div>
      {!props.isAuthenticated ? (
        <Box sx={{ width: "100%", height: "100%" }}>
          <MainHeader />
          {errorBox}
          <Box
            sx={{
              height: "100%",
              display: "flex",
              justifyContent: "center",
              alignItems: "center",
            }}
          >
            <Paper
              variant="outlined"
              sx={{
                width: "600px",
                p: { xs: 2, sm: 3 },
              }}
            >
              <Box
                sx={{ display: "flex", alignItems: "center" }}
                position="absolute"
              >
                <IconButton color="primary" onClick={handleBack}>
                  <ArrowBackIcon />
                </IconButton>
              </Box>

              <Typography variant="h4" align="center">
                Admin section
              </Typography>

              <Box
                sx={{
                  display: "flex",
                  justifyContent: "center",
                  mt: 5,
                  mb: 3,
                  px: { xs: "10%", sm: "20%" },
                }}
              >
                <TextField
                  id="username"
                  label="Username"
                  value={username}
                  onChange={(e) => setUsername(e.target.value)}
                  fullWidth
                />
              </Box>
              <Box
                sx={{
                  display: "flex",
                  justifyContent: "center",
                  mb: 4,
                  px: { xs: "10%", sm: "20%" },
                }}
              >
                <TextField
                  id="password"
                  type="password"
                  label="Password"
                  value={password}
                  onChange={(e) => setPassword(e.target.value)}
                  fullWidth
                />
              </Box>
              <Box sx={{ display: "flex", justifyContent: "center" }}>
                <Button
                  color="primary"
                  variant="contained"
                  size="large"
                  onClick={handleLogin}
                  onKeyDown={(e) => console.log(e.key)}
                >
                  Login
                </Button>
              </Box>
            </Paper>
          </Box>
        </Box>
      ) : (
        <Redirect to="/settings" />
      )}
    </div>
  );
}

const mapStateToProps = (state) => ({
  isAuthenticated: state.auth.isAuthenticated,
});

export default connect(mapStateToProps, { login })(LoginPage);
