import * as React from "react";
import AppBar from "@mui/material/AppBar";
import Box from "@mui/material/Box";
import CssBaseline from "@mui/material/CssBaseline";
import Divider from "@mui/material/Divider";
import Drawer from "@mui/material/Drawer";
import IconButton from "@mui/material/IconButton";
import InboxIcon from "@mui/icons-material/MoveToInbox";
import List from "@mui/material/List";
import ListItem from "@mui/material/ListItem";
import ListItemIcon from "@mui/material/ListItemIcon";
import ListItemText from "@mui/material/ListItemText";
import MailIcon from "@mui/icons-material/Mail";
import MenuIcon from "@mui/icons-material/Menu";
import Toolbar from "@mui/material/Toolbar";
import Typography from "@mui/material/Typography";
import {
  FormControl,
  InputAdornment,
  InputLabel,
  MenuItem,
  Select,
  TextField,
} from "@mui/material";
import Grid from "@mui/material/Grid";
import Container from "@mui/material/Container";
import Paper from "@mui/material/Paper";
import CheckIcon from "@mui/icons-material/Check";
import TypeTable from "../../components/tables/TypeTable";
import SignTable from "../../components/tables/SignTable";
import { useEffect, useRef, useState } from "react";
import axios from "axios";
import EmailTable from "../../components/tables/EmailTable";
import Button from "@mui/material/Button";

function TypeSelect({ selectedType, changeHandle }) {
  const [types, setTypes] = React.useState([]);

  const handleChange = (event) => {
    if (changeHandle) {
      changeHandle(event.target.value);
    }
  };

  useEffect(() => {
    axios
      .get("http://localhost:8000/api/types/")
      .then((resp) => {
        setTypes(resp.data);
      })
      .catch((err) => console.log(err));
  }, []);

  return (
    <Box
      sx={{
        display: "flex",
        alignItems: "center",
        ml: 2,
        my: 6,
        maxWidth: 150,
      }}
    >
      <FormControl fullWidth>
        <InputLabel id="type-select-input">Type</InputLabel>
        <Select
          labelId="type-select-label"
          id="type-select"
          value={selectedType}
          label="Type"
          onChange={handleChange}
        >
          {types.map((type) => {
            return (
              <MenuItem key={type.type_id} value={type.type_id}>
                {type.type}
              </MenuItem>
            );
          })}
        </Select>
      </FormControl>
    </Box>
  );
}
//TODO insert add new sign to email
export default function SettingsEmailInfo({ match }) {
  const [data, setData] = useState({
    email_id: 0,
    subject: "",
    sender: "",
    recipient: "",
    date: "",
    cc: "",
    body: "",
    type: { type_id: "", type: "" },
    sign: [],
  });
  const [emailStats, setEmailStats] = useState({
    occurrence: "",
    average_duration: "",
    average_correctness: "",
  });
  const [typeId, setTypeId] = useState("");
  const [allSigns, setAllSigns] = useState([]);
  const [selectedSign, setSelectedSign] = useState({ sign_id: -1, text: "" });

  const emailId = match.params.id;

  function changeType(type_id) {
    setData({ ...data, type: { type_id: type_id, type: "" } });
    setTypeId(type_id);
  }

  function handleUpdate() {
    const headers = {
      "Content-Type": "application/json",
    };
    axios("http://localhost:8000/api/emails/" + data.email_id + "/", {
      headers: headers,
      method: "PUT",
      withCredentials: true,
      data: {
        ...data,
        type: typeId,
        sign: data.sign.map((sign) => sign.sign_id),
      },
    }).catch((err) => console.log(err));
  }

  useEffect(() => {
    const headers = {
      "Content-Type": "application/json",
    };
    axios
      .get("http://localhost:8000/api/emails/" + emailId, {
        headers: headers,
      })
      .then((response) => {
        setData(response.data);
        setTypeId(response.data["type"].type_id);
      })
      .catch((err) => console.log(err));

    axios("http://localhost:8000/email-statistics/" + emailId + "/", {
      method: "POST",
      withCredentials: true,
      data: { email_id: emailId },
    }).then((res) => {
      setEmailStats({
        ...res.data,
        "Average correctness": res.data["Average correctness"] + "%",
      });
    });
    axios("http://localhost:8000/api/signs/", {
      method: "GET",
      withCredentials: true,
    }).then((res) => {
      setAllSigns(res.data);
    });
  }, []);

  function addSign() {
    if (selectedSign.sign_id !== -1) {
      setData({ ...data, sign: [...data.sign, selectedSign] });
      setSelectedSign({ sign_id: -1, text: "" });
    }
  }

  return (
    <Box>
      <Box sx={{ display: "flex", justifyContent: "space-evenly", mt: 5 }}>
        {Object.entries(emailStats).map(([key, value], index) => (
          <Paper
            key={index}
            sx={{
              display: "flex",
              flexDirection: "column",
              width: 160,
              height: 100,
              alignItems: "center",
              justifyContent: "center",
              backgroundColor: "#019592",
            }}
          >
            <Typography variant="h5"> {value}</Typography>
            <Typography>{key}</Typography>
          </Paper>
        ))}
      </Box>
      <Grid container direction="column" spacing={2} marginTop={4}>
        {Object.entries(data)
          .slice(0, 7)
          .map(([key, value], index) => (
            <Grid item container spacing={1} key={index}>
              <Grid item xs={3} sm={2}>
                <Typography
                  sx={{
                    textAlign: "right",
                    overflowWrap: "break-word",
                  }}
                >
                  {key}:
                </Typography>
              </Grid>
              <Grid item xs={9} sm={10}>
                <Typography
                  sx={{
                    overflowWrap: "break-word",
                  }}
                >
                  {value}
                </Typography>
              </Grid>
            </Grid>
          ))}
        <Grid item container spacing={1} alignItems="center">
          <Grid item xs={3} sm={2}>
            <Typography
              sx={{
                textAlign: "right",
                overflowWrap: "break-word",
              }}
            >
              Type:
            </Typography>
          </Grid>
          <Grid item xs={9} sm={10}>
            <TypeSelect selectedType={typeId} changeHandle={changeType} />
          </Grid>
        </Grid>
      </Grid>

      <Box sx={{ display: "flex", alignItems: "center", ml: 2 }}>
        <FormControl sx={{ width: 200 }}>
          <InputLabel id="sign-select-input">Add sign</InputLabel>
          <Select
            labelId="sign-select-label"
            id="sign-select"
            value={selectedSign.sign_id}
            label="Select sign"
          >
            {allSigns
              .filter(
                (sign) => !data.sign.some((s) => s.sign_id == sign.sign_id)
              )
              .map((sign) => {
                console.log(sign);
                return (
                  <MenuItem
                    key={sign.sign_id}
                    value={sign.sign_id}
                    onClick={(e) =>
                      setSelectedSign({
                        sign_id: sign.sign_id,
                        text: sign.text,
                      })
                    }
                  >
                    {sign.text}
                  </MenuItem>
                );
              })}
          </Select>
        </FormControl>
        <Button
          variant="contained"
          size="large"
          onClick={addSign}
          sx={{ ml: 4 }}
        >
          Add
        </Button>
      </Box>

      <SignTable
        signs={data.sign}
        handleDelete={(selectedIDs) =>
          setData({
            ...data,
            sign: data.sign.filter(
              (sign) => !selectedIDs.some((id) => id === sign.sign_id)
            ),
          })
        }
      />
      <Box
        sx={{ display: "flex", justifyContent: "center", my: 5 }}
        onClick={handleUpdate}
      >
        <Button variant="contained">Save</Button>
      </Box>
    </Box>
  );
}
