import * as React from "react";
import Box from "@mui/material/Box";
import IconButton from "@mui/material/IconButton";
import Typography from "@mui/material/Typography";
import { InputAdornment, TextField, ThemeProvider } from "@mui/material";
import Grid from "@mui/material/Grid";
import TypeTable from "../../components/tables/TypeTable";
import SignTable from "../../components/tables/SignTable";
import { useEffect, useState } from "react";
import axios from "axios";
import CheckCircleIcon from "@mui/icons-material/CheckCircle";

function SettingsGeneral() {
  const [settings, setSettings] = useState([]);
  const [signs, setSigns] = useState([]);

  useEffect(() => {
    axios("http://localhost:8000/api/settings/", {
      method: "GET",
      withCredentials: true,
    }).then((res) => {
      setSettings(res.data);
    });

    axios("http://localhost:8000/api/signs/", {
      method: "GET",
      withCredentials: true,
    }).then((res) => {
      setSigns(res.data);
    });
  }, []);

  function handleTextFieldChange(e, index) {
    let value = e.target.value;

    if (index === 1) {
      if (value < 0 || value > 100) {
        return;
      }
    }
    let updatedSettings = [...settings];
    updatedSettings[index].value = e.target.value;

    setSettings(updatedSettings);
  }

  function updateSettingItem(setting) {
    const headers = {
      "Content-Type": "application/json",
    };
    axios("http://localhost:8000/api/settings/" + setting.setting_id + "/", {
      headers: headers,
      method: "PUT",
      withCredentials: true,
      data: setting,
    });
  }

  return (
    <Box>
      {settings.map((setting, index) => (
        <Box
          sx={{
            display: "flex",
            alignItems: "center",
            mt: "55px",
            ml: "15px",
          }}
          key={index}
        >
          <Typography align="right" width="30%" mr={2}>
            {setting.item}
          </Typography>
          <Box sx={{ width: "70%" }}>
            <TextField
              type="number"
              sx={{ width: "60%" }}
              value={setting.value}
              onChange={(e) => handleTextFieldChange(e, index)}
              onKeyPress={(e) => console.log(e.key)}
              InputProps={{
                endAdornment: (
                  <InputAdornment position="end">
                    <IconButton
                      color="primary"
                      onClick={(e) => updateSettingItem(setting)}
                    >
                      <CheckCircleIcon />
                    </IconButton>
                  </InputAdornment>
                ),
              }}
              id="username"
            />
          </Box>
        </Box>
      ))}
      <Grid container spacing={0} sx={{ mt: 10 }}>
        <Grid item xs={12} md={6}>
          <TypeTable />
        </Grid>
        <Grid item xs={12} md={6}>
          <SignTable signs={signs} allowCreate={true} />
        </Grid>
      </Grid>
    </Box>
  );
}

export default SettingsGeneral;
