import * as React from "react";
import AppBar from "@mui/material/AppBar";
import Box from "@mui/material/Box";
import Divider from "@mui/material/Divider";
import Drawer from "@mui/material/Drawer";
import IconButton from "@mui/material/IconButton";
import InboxIcon from "@mui/icons-material/MoveToInbox";
import List from "@mui/material/List";
import ListItem from "@mui/material/ListItem";
import ListItemIcon from "@mui/material/ListItemIcon";
import ListItemText from "@mui/material/ListItemText";
import MailIcon from "@mui/icons-material/Mail";
import MenuIcon from "@mui/icons-material/Menu";
import Toolbar from "@mui/material/Toolbar";
import Typography from "@mui/material/Typography";
import LogoutIcon from "@mui/icons-material/Logout";
import Container from "@mui/material/Container";
import SettingsGeneral from "./settingsGeneral";
import {
  Link,
  Route,
  Switch,
  useHistory,
  useLocation,
  useRouteMatch,
} from "react-router-dom";
import SettingsGameruns from "./settingsGameruns";
import SettingsEmailInfo from "./settingsEmailInfo";
import SettingsGamerunInfo from "./settingsGamerunInfo";
import SettingsEmails from "./settingsEmails";
import EmailForm from "../../components/EmailForm";
import { createTheme } from "@mui/material/styles";
import { TextField } from "@mui/material";
import PropTypes from "prop-types";
import { connect } from "react-redux";
import { logout } from "../../actions/auth";

const drawerWidth = 240;

SettingsPage.propTypes = {
  auth: PropTypes.object.isRequired,
  logout: PropTypes.func.isRequired,
};

function SettingsPage(props) {
  const { window } = props;
  const [mobileOpen, setMobileOpen] = React.useState(false);
  let match = useRouteMatch();
  const handleDrawerToggle = () => {
    setMobileOpen(!mobileOpen);
  };

  const drawer = (
    <div>
      <Toolbar />
      <Divider />

      <List>
        {["General", "Emails", "Gameruns"].map((text, index) => (
          <Box
            key={index}
            component={Link}
            to={`${match.path}/` + text.toLowerCase()}
            style={{ textDecoration: "none", color: "#ffffff" }}
          >
            <ListItem button key={text}>
              <ListItemIcon>
                {index % 2 === 0 ? <InboxIcon /> : <MailIcon />}
              </ListItemIcon>

              <ListItemText primary={text} />
            </ListItem>
          </Box>
        ))}
        <Link style={{ textDecoration: "none", color: "#ffffff" }} to="/">
          <ListItem
            button
            key={"Logout"}
            onClick={props.logout}
            sx={{ mt: 40 }}
          >
            <ListItemIcon>
              <LogoutIcon />
            </ListItemIcon>
            <ListItemText primary={"Logout"} />
          </ListItem>
        </Link>
      </List>
    </div>
  );

  const container =
    window !== undefined ? () => window().document.body : undefined;

  return (
    <Box sx={{ display: "flex" }}>
      <AppBar
        position="fixed"
        sx={{
          width: { sm: `calc(100% - ${drawerWidth}px)` },
          ml: { sm: `${drawerWidth}px` },
        }}
      >
        <Toolbar>
          <IconButton
            aria-label="open drawer"
            edge="start"
            onClick={handleDrawerToggle}
            sx={{ mr: 2, display: { sm: "none" } }}
          >
            <MenuIcon />
          </IconButton>
          <Typography variant="h6" noWrap component="div">
            Responsive drawer
          </Typography>
        </Toolbar>
      </AppBar>
      <Box
        component="nav"
        sx={{ width: { sm: drawerWidth }, flexShrink: { sm: 0 } }}
      >
        <Drawer
          container={container}
          variant="temporary"
          open={mobileOpen}
          onClose={handleDrawerToggle}
          ModalProps={{
            keepMounted: true,
          }}
          sx={{
            display: { xs: "block", sm: "none" },
            "& .MuiDrawer-paper": {
              boxSizing: "border-box",
              width: drawerWidth,
            },
          }}
        >
          {drawer}
        </Drawer>
        <Drawer
          variant="permanent"
          sx={{
            display: { xs: "none", sm: "block" },
            "& .MuiDrawer-paper": {
              boxSizing: "border-box",
              width: drawerWidth,
            },
          }}
        >
          {drawer}
        </Drawer>
      </Box>
      <Container>
        <Toolbar />
        <Switch>
          <Route path={`${match.path}/general`} component={SettingsGeneral} />
          <Route
            path={`${match.path}/emails`}
            exact
            component={SettingsEmails}
          />
          <Route
            path={`${match.path}/gameruns`}
            exact
            component={SettingsGameruns}
          />
          <Route path={`*/emails/:id`} component={SettingsEmailInfo} />
          <Route
            path={`${match.path}/gameruns/:id`}
            component={SettingsGamerunInfo}
          />
          <Route path={`${match.path}/new_email`} component={EmailForm} />
        </Switch>
      </Container>
    </Box>
  );
}

const mapStateToProps = (state) => ({
  auth: state.auth,
});

export default connect(mapStateToProps, { logout })(SettingsPage);
