import Paper from "@mui/material/Paper";
import Box from "@mui/material/Box";
import { Button, Typography } from "@mui/material";
import { useEffect, useState } from "react";
import Grid from "@mui/material/Grid";
import axios from "axios";
import { Link } from "react-router-dom";
import CheckIcon from "@mui/icons-material/Check";
import CloseIcon from "@mui/icons-material/Close";
import { useLocation } from "react-router";

export default function SummaryPage(props) {
  const [msg, setMsg] = useState();
  const location = useLocation();

  const [emails, setEmails] = useState([]);

  useEffect(() => {
    if (location.nickname) {
      window.localStorage.setItem("nickname", location.nickname);
    }

    axios("http://localhost:8000/summary/", {
      method: "GET",
      withCredentials: true,
    }).then((res) => {
      setEmails(res.data);
      setMsg(
        window.localStorage.getItem("username") +
          ", You have " +
          res.data.filter((email) => email.answer.correctness === true).length +
          "/" +
          res.data.length +
          " correct"
      );
      console.log(res.data);
    });
  }, [location]);

  const PlayAgainButton = (
    <Box
      sx={{
        display: "flex",
        width: "100%",
        justifyContent: "center",
        my: 4,
      }}
    >
      <Button
        sx={{ marginX: "auto" }}
        variant="contained"
        component={Link}
        to="/username"
      >
        play again
      </Button>
    </Box>
  );

  function EmailWindow(props) {
    return (
      <Paper sx={{ width: "60%", height: 300 }}>
        <Box
          sx={{
            display: "flex",
            flexDirection: "column",
            width: "95%",
            height: "20%",
            margin: "auto",
            justifyContent: "center",
          }}
        >
          <Typography variant="h5">{props.currentEmail.subject}</Typography>
          <Typography variant="body2">{props.currentEmail.sender}</Typography>
        </Box>
        <Box
          sx={{
            width: "95%",
            height: "70%",
            margin: "auto",
          }}
        >
          <Paper
            sx={{ width: "100%", height: "100%", overflowY: "auto", border: 1 }}
          >
            <Typography
              sx={{ wordWrap: "break-word", padding: 2 }}
              variant="body2"
            >
              {props.currentEmail.body}
            </Typography>
          </Paper>
        </Box>
      </Paper>
    );
  }

  return (
    <div>
      <Paper
        sx={{
          width: "95%",
          height: "10vh",
          display: "flex",
          alignItems: "center",
          justifyContent: "center",
          margin: "auto",
          mt: 1,
        }}
      >
        {msg}
      </Paper>
      {PlayAgainButton}
      <Grid container spacing={6}>
        {emails.map((val, index) => (
          <Grid item container key={index}>
            <Grid item xs={12} sm={6}>
              <Box
                sx={{
                  display: "flex",
                  width: "100%",
                  justifyContent: "center",
                }}
              >
                <EmailWindow currentEmail={val.email} />
              </Box>
            </Grid>
            <Grid item xs={12} sm={6}>
              <Paper
                sx={{
                  margin: "0 auto",
                  width: "40%",
                  height: 300,
                  padding: 2,
                  display: "flex",
                  flexDirection: "column",
                }}
              >
                <Typography>
                  Average correctness: {val.average_correctness}%
                </Typography>
                <Typography>Your time: {val.players_duration}</Typography>

                <Typography>
                  Average duration: {val.average_duration}
                </Typography>
                <Box
                  sx={{
                    display: "flex",
                    flex: 1,
                    flexDirection: "column",
                    justifyContent: "flex-end",
                  }}
                >
                  <Typography variant="h6">
                    Your answer:
                    {val.answer.player_answer === true
                      ? "Phishing"
                      : "Legitimate"}
                    {val.answer.correctness === true ? (
                      <CheckIcon sx={{ color: "green" }} />
                    ) : (
                      <CloseIcon sx={{ color: "red" }} />
                    )}
                  </Typography>
                </Box>
              </Paper>
            </Grid>
          </Grid>
        ))}
      </Grid>
      {PlayAgainButton}
    </div>
  );
}
